==> haskell-casa-types-0.0.2-540-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-casa-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 casa-types
version:              0.0.2
visibility:           public
id:                   casa-types-0.0.2-H8Jg8sCDkTdAzehaTmLD4
key:                  casa-types-0.0.2-H8Jg8sCDkTdAzehaTmLD4
license:              BSD-3-Clause
copyright:            2018-2019 FP Complete
maintainer:           chrisdone@fpcomplete.com
author:               Chris Done
synopsis:             Types for Casa
description:          Types for Casa <https://casa.fpcomplete.com/>
category:             Development
abi:                  305d2812214c09aca0f98376cb16561f
exposed:              True
exposed-modules:      Casa.Types
hidden-modules:       Paths_casa_types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/casa-types-0.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/casa-types-0.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/casa-types-0.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-casa-types
hs-libraries:         HScasa-types-0.0.2-H8Jg8sCDkTdAzehaTmLD4
depends:
    aeson-2.1.2.1-4jhjW2ARw2KEAv1jKZWvea
    attoparsec-0.14.4-H1Mg1If1sweSExoQVyuwM base-4.17.2.1
    base16-bytestring-1.0.2.0-5CqdDAFWvdCp6PyRr0Kc1 bytestring-0.11.5.3
    hashable-1.4.4.0-9qNl3SeJnhrLashClEgMWi
    path-pieces-0.2.1-3XB1w9Pq9G55ySSfgWLsAv
    persistent-2.14.5.1-1PRzoHrAqHWE8Jv8xE0OsC text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-casa-types/html/casa-types.haddock
haddock-html:         /usr/share/doc/haskell-casa-types/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-casa-types-0.0.2-541-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-casa-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 casa-types
version:              0.0.2
visibility:           public
id:                   casa-types-0.0.2-30oIuMhqb1eG9dUmZH1rAV
key:                  casa-types-0.0.2-30oIuMhqb1eG9dUmZH1rAV
license:              BSD-3-Clause
copyright:            2018-2019 FP Complete
maintainer:           chrisdone@fpcomplete.com
author:               Chris Done
synopsis:             Types for Casa
description:          Types for Casa <https://casa.fpcomplete.com/>
category:             Development
abi:                  403c502dd177614267be7112af13615b
exposed:              True
exposed-modules:      Casa.Types
hidden-modules:       Paths_casa_types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/casa-types-0.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/casa-types-0.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/casa-types-0.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-casa-types
hs-libraries:         HScasa-types-0.0.2-30oIuMhqb1eG9dUmZH1rAV
depends:
    aeson-2.1.2.1-DB2WsLvgTWYJbtB30Xr8uJ
    attoparsec-0.14.4-4RzuPxfXaMJ4ix17ZyY6Fu base-4.17.2.1
    base16-bytestring-1.0.2.0-LEEZwYejCoZIthDQuiR9Zl
    bytestring-0.11.5.3 hashable-1.4.4.0-AxDm5kAgNA5AvAaNWXByLz
    path-pieces-0.2.1-3XB1w9Pq9G55ySSfgWLsAv
    persistent-2.14.5.1-1hhuiQo9MOG5DN4C7W6y1U text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-casa-types/html/casa-types.haddock
haddock-html:         /usr/share/doc/haskell-casa-types/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
